@@ -7,44 +7,46 @@
  */
 
 #include "event.h"
-#include "../debug.h"
+#include "debug.h"
 
 using namespace KGAPI2;
 
-namespace {
+namespace
+{
 static constexpr const char *EventIdProperty = "EventId";
+static constexpr const char *EventHangoutLinkProperty = "EventHangoutLink";
 }
 
 class Q_DECL_HIDDEN Event::Private
 {
-  public:
+public:
     QString id;
     bool deleted = false;
     bool useDefaultReminders = false;
 };
 
-Event::Event():
-    Object(),
-    KCalendarCore::Event(),
-    d(new Private)
+Event::Event()
+    : Object()
+    , KCalendarCore::Event()
+    , d(new Private)
 {
 }
 
-Event::Event(const Event &other):
-    Object(other),
-    KCalendarCore::Event(other),
-    d(new Private(*(other.d)))
+Event::Event(const Event &other)
+    : Object(other)
+    , KCalendarCore::Event(other)
+    , d(new Private(*(other.d)))
 {
 }
 
-Event::Event(const KCalendarCore::Event &other):
-    Object(),
-    KCalendarCore::Event(other),
-    d(new Private)
+Event::Event(const KCalendarCore::Event &other)
+    : Object()
+    , KCalendarCore::Event(other)
+    , d(new Private)
 {
 }
 
-Event::~Event()= default;
+Event::~Event() = default;
 
 bool Event::operator==(const Event &other) const
 {
@@ -66,7 +68,6 @@ bool Event::operator==(const Event &other) const
     return true;
 }
 
-
 bool Event::deleted() const
 {
     return d->deleted;
@@ -102,3 +103,13 @@ void Event::setId(const QString &id)
 {
     setCustomProperty("LIBKGAPI", EventIdProperty, id);
 }
+
+QString Event::hangoutLink() const
+{
+    return customProperty("LIBKGAPI", EventHangoutLinkProperty);
+}
+
+void Event::setHangoutLink(const QString &hangoutLink)
+{
+    setCustomProperty("LIBKGAPI", EventHangoutLinkProperty, hangoutLink);
+}
\ No newline at end of file
