@@ -6,8 +6,8 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#include "networkaccessmanagerfactory_p.h"
 #include "debug.h"
+#include "networkaccessmanagerfactory_p.h"
 
 #include <QNetworkAccessManager>
 
@@ -20,7 +20,7 @@ class QtNetworkAccessManagerFactory : public NetworkAccessManagerFactory
 public:
     QNetworkAccessManager *networkAccessManager(QObject *parent) const override
     {
-        auto *nam = new QNetworkAccessManager(parent);
+        auto nam = new QNetworkAccessManager(parent);
         nam->setStrictTransportSecurityEnabled(true);
         nam->setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
         return nam;
